
/******************************************************************************/
/*                        --安信可科技有限公司--                        */
/*
//  函数说明：main.c                                                              
//  说明：该程序用于测试lora模块                                                                
//  编写人员： sky                                                                 
// 编写日期： 2016-11-24                                                         
// 版本号:V1.0
// 维护日志：
//
//                                                          
*/ 
// 免责声明：该程序仅供参考学习，若自定义其他功能，请查看参考手册
// (c) Anxinke Corporation. All rights reserved.                                                               
/******************************************************************************/
#include "typedef.h"
#include "gpio.h"
#include "uart.h"

static bit bUartFlag;


/******************************************************************************/
// 函数名称：uartInit
//输入参数 :无
//输出参数：无
// 函数功能:设置好定时器0的工作模式
/******************************************************************************/
void uartInit(void)
{
    AUXR |= 0x80;//定时器0位IT模式 
    TMOD &= 0xF0; //设置定时器为模式0(16位自动重装载)
	TL0 = (0xFFFF - MCU_FREQ / UART_BUAD) & 0xFF;//设置定时初值
	TH0 = ((0xFFFF - MCU_FREQ / UART_BUAD) >> 8) & 0xFF; //设置定时器初值
    TR0 = 0; //定时器0开始计时
    ET0 = 0; //使能定时器0中断
    EA = 1;
}

/******************************************************************************/
// 函数名称:uartSendData
//输入参数:ucData发送字节
//输出参数:无
//函数功能:使能串口发送一个字节数据
/******************************************************************************/
void uartSendData(u8 ucData)
{
    u8 ucCnt;
    UART_TX_LOW(); //串口起始位开始
    TR0 = 1; //定时器0开始计时
    ET0 = 1; //使能定时器0中断
    bUartFlag = ON; 
    while(bUartFlag == ON);
	/*
	 *由地位开始，将数据通过串口输出
	*/
    for (ucCnt = 0; ucCnt < 8; ucCnt++) {
        UART_TX_SET(ucData & 0x01);
        ucData >>= 1;
        bUartFlag = ON; 
        while(bUartFlag == ON);
    }
    UART_TX_HIGH(); 
    bUartFlag = ON; 
    while(bUartFlag == ON);
    TR0 = 0;
    ET0 = 0;
}
/******************************************************************************/
// 函数名称uartSendString 
// 输入参数:ps:字符串首地址
// 输出参数:无
// 串口功能:发送字符串通过串口输出
/******************************************************************************/
void uartSendString(char *pS)
{
    while (*pS)                     
    {
        uartSendData(*pS++);     
    }
}

/******************************************************************************/
// 函数名称time0ISR 
// 输入参数:无
// 输出参数:w无
//函数功能:串口0服务函数
/******************************************************************************/
void time0ISR(void) interrupt 1 using 1
{
    EA = 0;
    bUartFlag = OFF;
    EA = 1;
}






